#
# spec file for package swell-foop
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           swell-foop
Version:        41.1
Release:        1.8
Summary:        Same Game for GNOME
License:        GPL-2.0-or-later
Group:          Amusements/Games/Board/Puzzle
URL:            https://wiki.gnome.org/Apps/Swell_Foop
Source0:        https://download.gnome.org/sources/swell-foop/41/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.50
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.22.0
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(clutter-1.0) >= 1.14.0
BuildRequires:  pkgconfig(clutter-gtk-1.0) >= 1.5.0
BuildRequires:  pkgconfig(gee-0.8) >= 0.14.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.36
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0) >= 2.36.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24
BuildRequires:  pkgconfig(libgnome-games-support-1) >= 1.7.1

%description
Swell Foop is a puzzle game, of which the objective is to clear the
window of as many pieces as possible by clicking on groups of the same
colored pieces. That group will vanish and the pieces on top will fall
until there are none left or no more color groups.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/org.gnome.SwellFoop.desktop
%{_datadir}/dbus-1/services/org.gnome.SwellFoop.service
%{_datadir}/glib-2.0/schemas/org.gnome.SwellFoop.gschema.xml
%{_datadir}/icons/hicolor/
%{_datadir}/metainfo/org.gnome.SwellFoop.appdata.xml

%files lang -f %{name}.lang

%changelog
* Thu Apr 14 2022 Emily Gonyer <emilyyrose@gmail.com>
- Update to version 41.1:
  + Fixed flatpak build.
  + Changed screenshots location.
  + Updated translations.
* Mon Sep 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.0.1:
  + Fixed versioning in appdata.
- Changes from version 41.0:
  + Updated translations.
* Fri Aug  6 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.alpha:
  + Fixed swell foop not starting from launcher.
  + Updated icon.
  + Updated translations.
* Fri Apr 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.1:
  + Fixed application not starting from launcher.
  + Updated translations.
* Sat Mar 20 2021 Michael Gorse <mgorse@suse.com>
- Update to version 40.0:
  + Use unowned for GtkChild fields.
  + Don't use multilib on arches where it doesn't exist.
  + Updated translations.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Updated translations.
* Tue Feb  9 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.beta:
  + Support window resizing.
  + Updated translations.
- Add pkgconfig(libgnome-games-support-1) and pkgconfig(gee-0.8)
  BuildRequires: new dependencies.
- Drop swell-foop-vala-syntax.patch: fixed upstream.
* Wed Oct  7 2020 malcolmlewis@opensuse.org
- Add swell-foop-vala-syntax.patch: Don't use unsupported vala
  syntax, (glgo#GNOME/swell-foop!20).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Oct 15 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Fixed crash.
  + Updated translations.
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Wed Sep  4 2019 dimstar@opensuse.org
- Update to version 3.33.92:
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Updated translations.
* Mon Feb 18 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Updated translations.
- Changes to version 3.31.90:
  + Added tests to validate appdata and desktop.
  + Set up flatpak nightly.
  + Updated translations.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.1:
  + Build fixes for flathub deployment.
  + Meson build fix.
  + Removed appmenu.
  + Updated translations.
* Sun Sep 16 2018 badshah400@gmail.com
- Update to version 3.30.0:
  + Updated translations.
  + Build fixes.
* Sat Jun 23 2018 luc14n0@linuxmail.org
- Update to version 3.29.3:
  + Updated translations.
* Tue Mar 13 2018 luc14n0@linuxmail.org
- Update to version 3.28.0:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb 27 2018 luc14n0@linuxmail.org
- Update to version 3.27.92:
  + Updated translations.
- Drop update-desktop-files BuildRequires and its macro: they are
  no longer required anymore.
- Drop unneeded standard BuildRoot tag declaration: RPM already
  handles this itself.
* Wed Feb 21 2018 dimstar@opensuse.org
- Update to version 3.27.91:
  + Meson build fixes.
  + Updated translations.
* Thu Feb  8 2018 luc14n0@linuxmail.org
- Update to version 3.27.90.1:
  + Build fixes - both meson and autotools.
- Add gmodule-2.0 and gobject-2.0 pkgconfig modules BuildRequires
  to avoid implicit dependencies.
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Minor user interface updates.
  + Gettext migration.
  + Added meson build.
  + Updated translations.
- Drop intltool BuildRequires: no longer needed as upstream
  migrated to gettext.
- Switch to meson build system:
  + Add meson BuildRequires.
  + Replace configure/make/make_install macros with
    meson/meson_build/meson_install.
* Tue Nov 14 2017 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + Updated translations.
- Update Url to https://wiki.gnome.org/Apps/Swell%%20Foop: current
  Swell Foop's web page.
- Drop %%glib2_gsettings_schema_*, %%desktop_database_*,
  %%icon_theme_cache_* scriptlets and
  %%glib2_gsettings_schema_requires macro: the functionality now is
  covered by RPM file triggers.
- Add fdupes BuildRequires and its macro for removal of duplicates
  under the data directory.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Only bind the Enter keypress when needed.
  + Updated translations.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Tue Nov 22 2016 dimstar@opensuse.org
- Update to version 3.23.2:
  + Updated translations.
* Thu Nov 10 2016 dimstar@opensuse.org
- Update to version 3.22.2:
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Added content ratings.
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Updated translations.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Updated translations.
* Tue Aug 16 2016 dimstar@opensuse.org
- Update to version 3.21.90:
  + Updated appdata.
  + Disable main stack's transition.
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Use a valid dbus name as app id.
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Updated AppData to spec version 0.7.
  + Updated translations.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Stop using deprecated gnome-common.
  + Add pre-commit and pre-applypatch hooks.
  + Updated translations.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 3.19.3:
  + Updated appdata and doap.
  + Updated translations.
* Tue Nov 10 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Tue Sep 15 2015 zaitor@opensuse.org
- Update to version 3.17.92:
  + Updated translations.
* Wed Sep  2 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Always show the new game button.
  + Updated translations.
* Wed Aug 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix display of new game button outside of GNOME.
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Provide symbolic icon.
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Updated About dialog.
  + Removed New Game from app menu.
  + Updated translations.
* Mon Jan 26 2015 dimstar@opensuse.org
- Update to version 3.15.4:
  + No new game confirmation before first move.
  + Fixed keyboard navigation glitch.
  + Updated translations.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Switched to appstream-util validate.
  + Updated translations.
* Wed Nov 19 2014 zaitor@opensuse.org
- Update to version 3.15.1:
  + First-run hint screen implemented.
  + Use set_accels_for_action.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Appdata: update screenshot size.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Region should be highlighted immediately after blocks fall.
  + Allow clearing blocks with the Enter key.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Minor changes.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Support touch screens.
  + Use dark theme.
  + Headerbar for preferences dialog.
  + Replace usage of deprecated API.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Fix touch screen tapping.
  + Bump clutter dep to 1.14.0, clutter-gtk to 1.4.0.
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated help.
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Appdata: update screenshot size.
  + Updated translations.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Appdata: specify project_group.
  + Add a confirmation dialog when starting a new game.
  + New game button: use refresh icon and add tooltip.
* Tue Dec 17 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + New app icon.
  + Use a GtkHeaderBar.
  + Autoscroll to new score in scores dialog.
  + Updated translations.
* Tue Oct 29 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Remove BugBuddy support.
  + Update AppData.
  + Updated translations.
* Sun Oct 13 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Add appdata file.
  + Add high contrast icons.
  + Updated translations.
- Add %%icon_theme_cache_post/un scriptlets for the HighContrast
  icons.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Fix preferences dialog.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Initial package, version 3.7.90: split-off from gnome-games.
